
# Sapsuccessfactors Connector

> By understanding what employees need, how they work, and what motivates them, you can put people at the heart of your HR strategy.


🔗 https://www.sap.com/

| Actions |
| ------- |
| [**Pull jobs**](docs/pull_jobs.md) |
| [**Push profile**](docs/push_profile.md) |
